@@ -3,6 +3,7 @@ import uuid
 import boto3
 import psycopg2
 
+from datetime import datetime, timezone
 from typing import Any, Dict, List, Tuple
 
 class BucketType:
@@ -109,6 +110,14 @@ class SimpleStorageService:
             except:
                 continue
 
+    def delete_all(self, bucket_name:str, prefix:str) -> None:
+        current_date = datetime.now(timezone.utc)
+        bucket = self._resource.Bucket(bucket_name)
+
+        for object in bucket.objects.filter(Prefix=prefix):
+            if (((current_date - object.last_modified).total_seconds() / 60) / 60) > 1:
+                object.delete()
+
 class PostgresRelationalDatabaseService:
     """
     Useful class to manage the specific relational database service for postgres
@@ -124,6 +133,12 @@ class PostgresRelationalDatabaseService:
             database=os.getenv("DB_NAME")
         )
 
+    def close(self) -> None:
+        try:
+            self._connection.close()
+        finally:
+            self._connection = None
+
     def _convert_columns_to_tuple(self, columns:Any) -> Tuple[str, Tuple[Any]]:
         if type(columns) == dict:
             keys = list(columns.keys())
@@ -132,6 +147,13 @@ class PostgresRelationalDatabaseService:
         else:
             return ', '.join(columns), None, ', '.join(['%s' for _ in range(len(columns))])
 
+    def get(self, query:str, vars:tuple) -> list:
+        with self._connection.cursor() as cursor:
+            cursor.execute(query, vars)
+            response = cursor.fetchall()
+            self._connection.commit()
+            return response
+
     def get_column(self, table_name:str, return_column:str, condition_column:str, condition_value:Any) -> Any:
         with self._connection.cursor() as cursor:
             cursor.execute(
@@ -204,3 +226,17 @@ class PostgresRelationalDatabaseService:
                 vars_list=values
             )
             self._connection.commit()
+
+    def delete(self, table_name:str, where:str=None) -> None:
+        if where is None:
+            where = ''
+        else:
+            where = f'WHERE {where}'
+
+        with self._connection.cursor() as cursor:
+            cursor.execute(
+                query=f'DELETE FROM {table_name} {where};',
+                vars=()
+            )
+            self._connection.commit()
+
